psychopy_ext.exp.ThickShapeStim
===============================

.. currentmodule:: psychopy_ext.exp

.. autoclass:: ThickShapeStim

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ThickShapeStim.__init__
      ~ThickShapeStim.contains
      ~ThickShapeStim.draw
      ~ThickShapeStim.overlaps
      ~ThickShapeStim.setAutoDraw
      ~ThickShapeStim.setAutoLog
      ~ThickShapeStim.setColor
      ~ThickShapeStim.setContrast
      ~ThickShapeStim.setDKL
      ~ThickShapeStim.setDepth
      ~ThickShapeStim.setFillColor
      ~ThickShapeStim.setFillRGB
      ~ThickShapeStim.setLMS
      ~ThickShapeStim.setLineColor
      ~ThickShapeStim.setLineRGB
      ~ThickShapeStim.setOpacity
      ~ThickShapeStim.setOri
      ~ThickShapeStim.setPos
      ~ThickShapeStim.setRGB
      ~ThickShapeStim.setSize
      ~ThickShapeStim.setUseShaders
      ~ThickShapeStim.setVertices
   
   

   
   
   